Line
====

.. currentmodule:: pywwt

.. autoclass:: Line
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Line.color
      ~Line.shape
      ~Line.width

   .. rubric:: Methods Summary

   .. autosummary::

      ~Line.add_point

   .. rubric:: Attributes Documentation

   .. autoattribute:: color
   .. autoattribute:: shape
   .. autoattribute:: width

   .. rubric:: Methods Documentation

   .. automethod:: add_point
